@@ -1,7 +1,9 @@
 package Org::To::HTML;
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-09-11'; # DATE
-our $VERSION = '0.232'; # VERSION
+our $DIST = 'Org-To-HTML'; # DIST
+our $VERSION = '0.233'; # VERSION
 
 use 5.010001;
 use strict;
@@ -383,6 +385,7 @@ sub export_timestamp {
 
 sub export_link {
     require Filename::Image;
+    require URI;
 
     my ($self, $elem) = @_;
 
@@ -390,21 +393,35 @@ sub export_link {
     my $link = $elem->link;
     my $looks_like_image = Filename::Image::check_image_filename(filename => $link);
     my $inline_images = $self->inline_images;
+
     if ($inline_images && $looks_like_image) {
         # TODO: extract to method e.g. settings
-        my $settings;
+        my $elem_settings;
         my $s = $elem;
         while (1) {
             $s = $s->prev_sibling;
             last unless $s && $s->isa("Org::Element::Setting");
-            $settings->{ $s->name } = $s->raw_arg;
+            $elem_settings->{ $s->name } = $s->raw_arg;
         }
         #use DD; dd $settings;
-        my $caption = $settings->{CAPTION};
+        my $caption = $elem_settings->{CAPTION};
+
+        # TODO: extract to method e.g. settings of Org::Document
+        my $doc_settings;
+        $s = $elem->document->children->[0];
+        while (1) {
+            $s = $s->next_sibling;
+            last unless $s && $s->isa("Org::Element::Setting");
+            $doc_settings->{ $s->name } = $s->raw_arg;
+        }
+        #use DD; dd $settings;
+        my $img_base = $doc_settings->{IMAGE_BASE};
+
+        my $url = defined($img_base) ? URI->new($link)->abs(URI->new($img_base)) : $link;
 
         push @$html, "<figure>" if defined $caption;
         push @$html, "<img src=\"";
-        push @$html, $link;
+        push @$html, "$url";
         push @$html, "\" />";
         push @$html, "<figcaption>", encode_entities($caption), "</figcaption>";
         push @$html, "</figure>" if defined $caption;
@@ -438,7 +455,7 @@ Org::To::HTML - Export Org document to HTML
 
 =head1 VERSION
 
-This document describes version 0.232 of Org::To::HTML (from Perl distribution Org-To-HTML), released on 2020-09-11.
+This document describes version 0.233 of Org::To::HTML (from Perl distribution Org-To-HTML), released on 2020-09-11.
 
 =head1 SYNOPSIS
 
